@@ -26,7 +26,7 @@
 #include <QJsonDocument>
 #include <QJsonArray>
 #include <QDir>
-#include <KIO/FileCopyJob>
+#include <KIO/StoredTransferJob>
 
 #include <utils.h>
 #include <resources/ResourcesModel.h>
@@ -46,8 +46,15 @@ FeaturedModel::FeaturedModel()
     *featuredCache = dir+QLatin1String("/featured-5.9.json");
 
     const QUrl featuredUrl(QStringLiteral("https://autoconfig.kde.org/discover/featured-5.9.json"));
-    KIO::FileCopyJob *getJob = KIO::file_copy(featuredUrl, QUrl::fromLocalFile(*featuredCache), -1, KIO::Overwrite | KIO::HideProgressInfo);
-    connect(getJob, &KIO::FileCopyJob::result, this, &FeaturedModel::refresh);
+    auto *getJob = KIO::storedGet(featuredUrl, KIO::NoReload, KIO::HideProgressInfo);
+    connect(getJob, &KIO::StoredTransferJob::result, this, [this, getJob](){
+        QFile f(*featuredCache);
+        if (!f.open(QIODevice::WriteOnly))
+            qWarning() << "could not open" << *featuredCache << f.errorString();
+        f.write(getJob->data());
+        f.close();
+        refresh();
+    });
 
     if (!ResourcesModel::global()->backends().isEmpty() && QFile::exists(*featuredCache))
         refresh();
@@ -57,7 +64,7 @@ void FeaturedModel::refresh()
 {
     QFile f(*featuredCache);
     if (!f.open(QIODevice::ReadOnly)) {
-        qWarning() << "couldn't open file" << *featuredCache;
+        qWarning() << "couldn't open file" << *featuredCache << f.errorString();
         return;
     }
     QJsonParseError error;
@@ -89,22 +96,18 @@ void FeaturedModel::setUris(const QVector<QUrl>& uris)
 
 static void filterDupes(QVector<AbstractResource *> &resources)
 {
-    QSet<QString> uri, dupeUri;
-    for(auto res: qAsConst(resources)) {
-        const auto id = res->appstreamId();
-        if (uri.contains(id))
-            dupeUri += id;
-        else
-            uri += id;
-    }
-
-    const auto appBackend = ResourcesModel::global()->currentApplicationBackend();
-    for(auto it = resources.begin(); it != resources.end(); ) {
-        const auto backend = (*it)->backend();
-        if (backend != appBackend && dupeUri.contains((*it)->appstreamId()))
+    const auto appsBackend = ResourcesModel::global()->currentApplicationBackend();
+    QHash<QString, AbstractResource*> resById;
+    for(auto it = resources.begin(); it!=resources.end(); ) {
+        auto id = (*it)->appstreamId();
+        auto curr = resById.value(id);
+        if (curr && curr->backend() == appsBackend) {
             it = resources.erase(it);
-        else
+        } else {
+            resources.removeAll(curr);
+            resById[id] = *it;
             ++it;
+        }
     }
 }
 
@@ -129,7 +132,7 @@ void FeaturedModel::removeResource(AbstractResource* resource)
     if (index<0)
         return;
 
-    beginRemoveRows({}, index, 0);
+    beginRemoveRows({}, index, index);
     m_resources.removeAt(index);
     endRemoveRows();
 }
